==> jc-1.4.0.tar.gz: ppg/lex/LexicalError.h <==
// public class ppg.lex.LexicalError

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class e19967fc0d8aa266 ppg_lex_LexicalError

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_ppg_lex_LexicalError_H_
#define _JC_ppg_lex_LexicalError_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_lex_LexicalError$sub_refs	_jc_ppg_lex_LexicalError$sub_refs;
typedef struct _jc_ppg_lex_LexicalError$sub_nonrefs	_jc_ppg_lex_LexicalError$sub_nonrefs;
typedef struct _jc_ppg_lex_LexicalError$refs	_jc_ppg_lex_LexicalError$refs;
typedef struct _jc_ppg_lex_LexicalError$nonrefs	_jc_ppg_lex_LexicalError$nonrefs;
typedef struct _jc_ppg_lex_LexicalError$object	_jc_ppg_lex_LexicalError$object;

typedef const struct _jc_ppg_lex_LexicalError$vmethods	_jc_ppg_lex_LexicalError$vmethods;
typedef const struct _jc_ppg_lex_LexicalError$vtable	_jc_ppg_lex_LexicalError$vtable;
typedef const struct _jc_ppg_lex_LexicalError$vtype	_jc_ppg_lex_LexicalError$vtype;

// Constructors
extern void _jc_ppg_lex_LexicalError$method$_init$84c8bccb0ecf3ee4(_jc_env *, struct _jc_ppg_lex_LexicalError$object *, struct _jc_java_lang_String$object *, jint, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_ppg_lex_LexicalError$method$filename$473a760a193a6af1(_jc_env *, struct _jc_ppg_lex_LexicalError$object *);
extern struct _jc_java_lang_String$object *_jc_ppg_lex_LexicalError$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_ppg_lex_LexicalError$object *);
extern jint _jc_ppg_lex_LexicalError$method$lineNumber$0f5ac400ac749ef4(_jc_env *, struct _jc_ppg_lex_LexicalError$object *);
extern struct _jc_java_lang_String$object *_jc_ppg_lex_LexicalError$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_lex_LexicalError$object *);
extern void _jc_ppg_lex_LexicalError$method$unparse$15ab4c442cf348a1(_jc_env *, struct _jc_ppg_lex_LexicalError$object *, struct _jc_java_io_OutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_ppg_lex_LexicalError$method_info$filename$473a760a193a6af1;
extern _jc_method _jc_ppg_lex_LexicalError$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_ppg_lex_LexicalError$method_info$lineNumber$0f5ac400ac749ef4;
extern _jc_method _jc_ppg_lex_LexicalError$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_ppg_lex_LexicalError$method_info$unparse$15ab4c442cf348a1;

// Virtual methods structure
struct _jc_ppg_lex_LexicalError$vmethods {
	struct _jc_java_lang_String$object	*(*filename$473a760a193a6af1)(_jc_env *, struct _jc_ppg_lex_LexicalError$object *);
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_ppg_lex_LexicalError$object *);
	jint	(*lineNumber$0f5ac400ac749ef4)(_jc_env *, struct _jc_ppg_lex_LexicalError$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_lex_LexicalError$object *);
	void	(*unparse$15ab4c442cf348a1)(_jc_env *, struct _jc_ppg_lex_LexicalError$object *, struct _jc_java_io_OutputStream$object *);
};

// Vtable
struct _jc_ppg_lex_LexicalError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_ppg_lex_LexicalError$vmethods	ppg_lex_LexicalError;
};

// Vtype
struct _jc_ppg_lex_LexicalError$vtype {
	_jc_type			type;
	_jc_ppg_lex_LexicalError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_lex_LexicalError$sub_refs {
	struct _jc_java_lang_String$object	*filename;
	struct _jc_java_lang_String$object	*message;
};

// Reference instance fields (object)
struct _jc_ppg_lex_LexicalError$refs {
    _jc_ppg_lex_LexicalError$sub_refs	ppg_lex_LexicalError;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_lex_LexicalError$sub_nonrefs {
	jint	lineNumber;
};

// Non-reference instance fields (object)
struct _jc_ppg_lex_LexicalError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_ppg_lex_LexicalError$sub_nonrefs	ppg_lex_LexicalError;
};

// Object instance structure
struct _jc_ppg_lex_LexicalError$object {
	_jc_ppg_lex_LexicalError$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_lex_LexicalError$vtype	*vtype;
	_jc_ppg_lex_LexicalError$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_lex_LexicalError$vtype _jc_ppg_lex_LexicalError$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_lex_LexicalError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_lex_LexicalError$class_object;

#endif	/* _JC_ppg_lex_LexicalError_H_ */

==> jc-1.4.6.tar.gz: ppg/lex/LexicalError.h <==
// public class ppg.lex.LexicalError

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class e19967fc0d8aa266 ppg_lex_LexicalError

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_ppg_lex_LexicalError_H_
#define _JC_ppg_lex_LexicalError_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_lex_LexicalError$sub_refs	_jc_ppg_lex_LexicalError$sub_refs;
typedef struct _jc_ppg_lex_LexicalError$sub_nonrefs	_jc_ppg_lex_LexicalError$sub_nonrefs;
typedef struct _jc_ppg_lex_LexicalError$refs	_jc_ppg_lex_LexicalError$refs;
typedef struct _jc_ppg_lex_LexicalError$nonrefs	_jc_ppg_lex_LexicalError$nonrefs;
typedef struct _jc_ppg_lex_LexicalError$object	_jc_ppg_lex_LexicalError$object;

typedef const struct _jc_ppg_lex_LexicalError$vmethods	_jc_ppg_lex_LexicalError$vmethods;
typedef const struct _jc_ppg_lex_LexicalError$vtable	_jc_ppg_lex_LexicalError$vtable;
typedef const struct _jc_ppg_lex_LexicalError$vtype	_jc_ppg_lex_LexicalError$vtype;

// Constructors
extern void _jc_ppg_lex_LexicalError$method$_init$84c8bccb0ecf3ee4(_jc_env *, struct _jc_ppg_lex_LexicalError$object *, struct _jc_java_lang_String$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_ppg_lex_LexicalError$method$filename$473a760a193a6af1(_jc_env *, struct _jc_ppg_lex_LexicalError$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_ppg_lex_LexicalError$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_ppg_lex_LexicalError$object *) _JC_JCNI_ATTR;
extern jint _jc_ppg_lex_LexicalError$method$lineNumber$0f5ac400ac749ef4(_jc_env *, struct _jc_ppg_lex_LexicalError$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_ppg_lex_LexicalError$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_lex_LexicalError$object *) _JC_JCNI_ATTR;
extern void _jc_ppg_lex_LexicalError$method$unparse$15ab4c442cf348a1(_jc_env *, struct _jc_ppg_lex_LexicalError$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_lex_LexicalError$method_info$filename$473a760a193a6af1;
extern _jc_method _jc_ppg_lex_LexicalError$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_ppg_lex_LexicalError$method_info$lineNumber$0f5ac400ac749ef4;
extern _jc_method _jc_ppg_lex_LexicalError$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_ppg_lex_LexicalError$method_info$unparse$15ab4c442cf348a1;

// Virtual methods structure
struct _jc_ppg_lex_LexicalError$vmethods {
	struct _jc_java_lang_String$object	*(*filename$473a760a193a6af1)(_jc_env *, struct _jc_ppg_lex_LexicalError$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_ppg_lex_LexicalError$object *) _JC_JCNI_ATTR;
	jint	(*lineNumber$0f5ac400ac749ef4)(_jc_env *, struct _jc_ppg_lex_LexicalError$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_lex_LexicalError$object *) _JC_JCNI_ATTR;
	void	(*unparse$15ab4c442cf348a1)(_jc_env *, struct _jc_ppg_lex_LexicalError$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_lex_LexicalError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_ppg_lex_LexicalError$vmethods	ppg_lex_LexicalError;
};

// Vtype
struct _jc_ppg_lex_LexicalError$vtype {
	_jc_type			type;
	_jc_ppg_lex_LexicalError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_lex_LexicalError$sub_refs {
	struct _jc_java_lang_String$object	*filename;
	struct _jc_java_lang_String$object	*message;
};

// Reference instance fields (object)
struct _jc_ppg_lex_LexicalError$refs {
    _jc_ppg_lex_LexicalError$sub_refs	ppg_lex_LexicalError;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_lex_LexicalError$sub_nonrefs {
	jint	lineNumber;
};

// Non-reference instance fields (object)
struct _jc_ppg_lex_LexicalError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_ppg_lex_LexicalError$sub_nonrefs	ppg_lex_LexicalError;
};

// Object instance structure
struct _jc_ppg_lex_LexicalError$object {
	_jc_ppg_lex_LexicalError$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_lex_LexicalError$vtype	*vtype;
	_jc_ppg_lex_LexicalError$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_lex_LexicalError$vtype _jc_ppg_lex_LexicalError$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_lex_LexicalError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_lex_LexicalError$class_object;

#endif	/* _JC_ppg_lex_LexicalError_H_ */
